@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:
  +-------------------------------------------------------------------------+
- | Copyright (C) 2002-2013 The Cacti Group                                 |
+ | Copyright (C) 2004-2017 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -75,6 +75,7 @@ static void spine_signal_handler(int spine_signal) {
 
 static int spine_fatal_signals[] = {
 	SIGINT,
+	SIGPIPE,
 	SIGSEGV,
 	SIGBUS,
 	SIGFPE,
@@ -90,23 +91,26 @@ static int spine_fatal_signals[] = {
 void install_spine_signal_handler(void) {
 	/* Set a handler for any fatal signal not already handled */
 	int i;
-	struct sigaction action;
+	struct sigaction sa;
 	void (*ohandler)(int);
 
-	for ( i=0; spine_fatal_signals[i]; ++i ) {
-		sigaction(spine_fatal_signals[i], NULL, &action);
-		if ( action.sa_handler == SIG_DFL ) {
-			action.sa_handler = spine_signal_handler;
-			sigaction(spine_fatal_signals[i], &action, NULL);
+	for (i=0; spine_fatal_signals[i]; ++i) {
+		sigaction(spine_fatal_signals[i], NULL, &sa);
+		if (sa.sa_handler == SIG_DFL) {
+			sa.sa_handler = spine_signal_handler;
+			sigemptyset(&sa.sa_mask);
+			sa.sa_flags = SA_RESTART;
+			sigaction(spine_fatal_signals[i], &sa, NULL);
 		}
 	}
 
-	for ( i=0; spine_fatal_signals[i]; ++i ) {
+	for (i=0; spine_fatal_signals[i]; ++i) {
 		ohandler = signal(spine_fatal_signals[i], spine_signal_handler);
-		if ( ohandler != SIG_DFL ) {
+		if (ohandler != SIG_DFL) {
 			signal(spine_fatal_signals[i], ohandler);
 		}
 	}
+
 	return;
 }
 
@@ -117,20 +121,20 @@ void install_spine_signal_handler(void) {
 void uninstall_spine_signal_handler(void) {
 	/* Remove a handler for any fatal signal handled */
 	int i;
-	struct sigaction action;
+	struct sigaction sa;
 	void (*ohandler)(int);
 
-	for ( i=0; spine_fatal_signals[i]; ++i ) {
-		sigaction(spine_fatal_signals[i], NULL, &action);
-		if ( action.sa_handler == spine_signal_handler ) {
-			action.sa_handler = SIG_DFL;
-			sigaction(spine_fatal_signals[i], &action, NULL);
+	for (i=0; spine_fatal_signals[i]; ++i) {
+		sigaction(spine_fatal_signals[i], NULL, &sa);
+		if (sa.sa_handler == spine_signal_handler) {
+			sa.sa_handler = SIG_DFL;
+			sigaction(spine_fatal_signals[i], &sa, NULL);
 		}
 	}
 
 	for ( i=0; spine_fatal_signals[i]; ++i ) {
 		ohandler = signal(spine_fatal_signals[i], SIG_DFL);
-		if ( ohandler != spine_signal_handler ) {
+		if (ohandler != spine_signal_handler) {
 			signal(spine_fatal_signals[i], ohandler);
 		}
 	}
