@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:
  +-------------------------------------------------------------------------+
- | Copyright (C) 2002-2012 The Cacti Group                                 |
+ | Copyright (C) 2004-2017 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -49,12 +49,11 @@
 	}
 
 DEFINE_SPINE_LOCK(snmp)
-DEFINE_SPINE_LOCK(thread)
 DEFINE_SPINE_LOCK(seteuid)
 DEFINE_SPINE_LOCK(ghbn)
-DEFINE_SPINE_LOCK(pipe)
 DEFINE_SPINE_LOCK(syslog)
 DEFINE_SPINE_LOCK(php)
+DEFINE_SPINE_LOCK(pend)
 DEFINE_SPINE_LOCK(php_proc_0)
 DEFINE_SPINE_LOCK(php_proc_1)
 DEFINE_SPINE_LOCK(php_proc_2)
@@ -68,12 +67,11 @@ DEFINE_SPINE_LOCK(php_proc_9)
 
 void init_mutexes() {
 	pthread_once((pthread_once_t*) get_attr(LOCK_SNMP_O),       init_snmp_lock);
-	pthread_once((pthread_once_t*) get_attr(LOCK_THREAD_O),     init_thread_lock);
 	pthread_once((pthread_once_t*) get_attr(LOCK_SETEUID_O),    init_seteuid_lock);
 	pthread_once((pthread_once_t*) get_attr(LOCK_GHBN_O),       init_ghbn_lock);
-	pthread_once((pthread_once_t*) get_attr(LOCK_PIPE_O),       init_pipe_lock);
 	pthread_once((pthread_once_t*) get_attr(LOCK_SYSLOG_O),     init_syslog_lock);
 	pthread_once((pthread_once_t*) get_attr(LOCK_PHP_O),        init_php_lock);
+	pthread_once((pthread_once_t*) get_attr(LOCK_PEND_O),       init_pend_lock);
 	pthread_once((pthread_once_t*) get_attr(LOCK_PHP_PROC_0_O), init_php_proc_0_lock);
 	pthread_once((pthread_once_t*) get_attr(LOCK_PHP_PROC_1_O), init_php_proc_1_lock);
 	pthread_once((pthread_once_t*) get_attr(LOCK_PHP_PROC_2_O), init_php_proc_2_lock);
@@ -91,10 +89,8 @@ pthread_mutex_t* get_lock(int lock) {
 
 	switch (lock) {
 	case LOCK_SNMP:       ret_val = &snmp_lock;       break;
-	case LOCK_THREAD:     ret_val = &thread_lock;     break;
 	case LOCK_SETEUID:    ret_val = &seteuid_lock;    break;
 	case LOCK_GHBN:       ret_val = &ghbn_lock;       break;
-	case LOCK_PIPE:       ret_val = &pipe_lock;       break;
 	case LOCK_SYSLOG:     ret_val = &syslog_lock;     break;
 	case LOCK_PHP:        ret_val = &php_lock;        break;
 	case LOCK_PHP_PROC_0: ret_val = &php_proc_0_lock; break;
@@ -107,6 +103,7 @@ pthread_mutex_t* get_lock(int lock) {
 	case LOCK_PHP_PROC_7: ret_val = &php_proc_7_lock; break;
 	case LOCK_PHP_PROC_8: ret_val = &php_proc_8_lock; break;
 	case LOCK_PHP_PROC_9: ret_val = &php_proc_9_lock; break;
+	case LOCK_PEND:       ret_val = &pend_lock;       break;
 	}
 
 	return ret_val;
@@ -117,10 +114,8 @@ pthread_once_t* get_attr(int locko) {
 
 	switch (locko) {
 	case LOCK_SNMP_O:       ret_val = &snmp_lock_o;       break;
-	case LOCK_THREAD_O:     ret_val = &thread_lock_o;     break;
 	case LOCK_SETEUID_O:    ret_val = &seteuid_lock_o;    break;
 	case LOCK_GHBN_O:       ret_val = &ghbn_lock_o;       break;
-	case LOCK_PIPE_O:       ret_val = &pipe_lock_o;       break;
 	case LOCK_SYSLOG_O:     ret_val = &syslog_lock_o;     break;
 	case LOCK_PHP_O:        ret_val = &php_lock_o;        break;
 	case LOCK_PHP_PROC_0_O: ret_val = &php_proc_0_lock_o; break;
@@ -133,6 +128,7 @@ pthread_once_t* get_attr(int locko) {
 	case LOCK_PHP_PROC_7_O: ret_val = &php_proc_7_lock_o; break;
 	case LOCK_PHP_PROC_8_O: ret_val = &php_proc_8_lock_o; break;
 	case LOCK_PHP_PROC_9_O: ret_val = &php_proc_9_lock_o; break;
+	case LOCK_PEND_O:       ret_val = &pend_lock_o;       break;
 	}
 
 	return ret_val;
