@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:
  +-------------------------------------------------------------------------+
- | Copyright (C) 2002-2013 The Cacti Group                                 |
+ | Copyright (C) 2004-2017 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -59,7 +59,11 @@ int ping_host(host_t *host, ping_t *ping) {
 
 		if (host->ping_method == PING_ICMP) {
 			if (set.icmp_avail == FALSE) {
-				SPINE_LOG_DEBUG(("Host[%i] DEBUG Falling back to UDP Ping Due to SetUID Issues", host->id));
+				if (is_debug_device(host->id)) {
+					SPINE_LOG(("Device[%i] DEBUG Falling back to UDP Ping Due to SetUID Issues", host->id));
+				}else{
+					SPINE_LOG_DEBUG(("Device[%i] DEBUG Falling back to UDP Ping Due to SetUID Issues", host->id));
+				}
 				host->ping_method = PING_UDP;
 			}
 		}
@@ -74,7 +78,7 @@ int ping_host(host_t *host, ping_t *ping) {
 			}
 		}else{
 			snprintf(ping->ping_status, 50, "0.000");
-			snprintf(ping->ping_response, SMALL_BUFSIZE, "PING: Host does not require ping");
+			snprintf(ping->ping_response, SMALL_BUFSIZE, "PING: Device does not require ping");
 			ping_result = HOST_UP;
 		}
 	}
@@ -156,11 +160,14 @@ int ping_host(host_t *host, ping_t *ping) {
 int ping_snmp(host_t *host, ping_t *ping) {
 	char *poll_result;
 	char *oid;
-	int num_oids_checked = 0;
 	double begin_time, end_time, total_time;
 	double one_thousand = 1000.00;
 
-	SPINE_LOG_DEBUG(("Host[%i] DEBUG: Entering SNMP Ping", host->id));
+	if (is_debug_device(host->id)) {
+		SPINE_LOG(("Device[%i] DEBUG: Entering SNMP Ping", host->id));
+	}else{
+		SPINE_LOG_DEBUG(("Device[%i] DEBUG: Entering SNMP Ping", host->id));
+	}
 
 	if (host->snmp_session) {
 		if ((strlen(host->snmp_community) != 0) || (host->snmp_version == 3)) {
@@ -193,24 +200,28 @@ int ping_snmp(host_t *host, ping_t *ping) {
 
 			/* do positive test cases first */
 			if (host->snmp_status == SNMPERR_UNKNOWN_OBJID) {
-				snprintf(ping->snmp_response, SMALL_BUFSIZE, "Host responded to SNMP");
+				snprintf(ping->snmp_response, SMALL_BUFSIZE, "Device responded to SNMP");
 				snprintf(ping->snmp_status, 50, "%.5f", total_time);
 				free(poll_result);
 				return HOST_UP;
 			}else if (host->snmp_status != SNMPERR_SUCCESS) {
-				SPINE_LOG_MEDIUM(("Host[%i] SNMP Ping Error: %s", host->id, snmp_api_errstring(host->snmp_status)));
-				snprintf(ping->snmp_response, SMALL_BUFSIZE, "Host did not respond to SNMP");
+				if (is_debug_device(host->id)) {
+					SPINE_LOG(("Device[%i] SNMP Ping Error: %s", host->id, snmp_api_errstring(host->snmp_status)));
+				}else{
+					SPINE_LOG_MEDIUM(("Device[%i] SNMP Ping Error: %s", host->id, snmp_api_errstring(host->snmp_status)));
+				}
+				snprintf(ping->snmp_response, SMALL_BUFSIZE, "Device did not respond to SNMP");
 				free(poll_result);
 				return HOST_DOWN;
 			}else{
-				snprintf(ping->snmp_response, SMALL_BUFSIZE, "Host responded to SNMP");
+				snprintf(ping->snmp_response, SMALL_BUFSIZE, "Device responded to SNMP");
 				snprintf(ping->snmp_status, 50, "%.5f", total_time);
 				free(poll_result);
 				return HOST_UP;
 			}
 		}else{
 			snprintf(ping->snmp_status, 50, "0.00");
-			snprintf(ping->snmp_response, SMALL_BUFSIZE, "Host does not require SNMP");
+			snprintf(ping->snmp_response, SMALL_BUFSIZE, "Device does not require SNMP");
 			return HOST_UP;
 		}
 	}else{
@@ -257,7 +268,11 @@ int ping_icmp(host_t *host, ping_t *ping) {
 	unsigned char  *packet;
 	char     *new_hostname;
 
-	SPINE_LOG_DEBUG(("Host[%i] DEBUG: Entering ICMP Ping", host->id));
+	if (is_debug_device(host->id)) {
+		SPINE_LOG(("Device[%i] DEBUG: Entering ICMP Ping", host->id));
+	}else{
+		SPINE_LOG_DEBUG(("Device[%i] DEBUG: Entering ICMP Ping", host->id));
+	}
 
 	/* remove "tcp:" from hostname */
 	new_hostname = remove_tcp_udp_from_hostname(host->hostname);
@@ -399,8 +414,13 @@ int ping_icmp(host_t *host, ping_t *ping) {
 
 					if (return_code < 0) {
 						if (errno == EINTR) {
-							SPINE_LOG_DEBUG(("Host[%i] DEBUG: Received EINTR", host->id));
+							if (is_debug_device(host->id)) {
+								SPINE_LOG(("Device[%i] DEBUG: Received EINTR", host->id));
+							}else{
+								SPINE_LOG_DEBUG(("Device[%i] DEBUG: Received EINTR", host->id));
+							}
 							/* call was interrupted by some system event */
+							usleep(10000);
 							goto keep_listening;
 						}
 					}else{
@@ -409,8 +429,12 @@ int ping_icmp(host_t *host, ping_t *ping) {
 
 						if (fromname.sin_addr.s_addr == recvname.sin_addr.s_addr) {
 							if ((pkt->icmp_type == ICMP_ECHOREPLY)) {
-								SPINE_LOG_DEBUG(("Host[%i] DEBUG: ICMP Host Alive, Try Count:%i, Time:%.4f ms", host->id, retry_count+1, (total_time)));
-								snprintf(ping->ping_response, SMALL_BUFSIZE, "ICMP: Host is Alive");
+								if (is_debug_device(host->id)) {
+									SPINE_LOG(("Device[%i] DEBUG: ICMP Device Alive, Try Count:%i, Time:%.4f ms", host->id, retry_count+1, (total_time)));
+								}else{
+									SPINE_LOG_DEBUG(("Device[%i] DEBUG: ICMP Device Alive, Try Count:%i, Time:%.4f ms", host->id, retry_count+1, (total_time)));
+								}
+								snprintf(ping->ping_response, SMALL_BUFSIZE, "ICMP: Device is Alive");
 								snprintf(ping->ping_status, 50, "%.5f", total_time);
 								free(new_hostname);
 								free(packet);
@@ -444,7 +468,11 @@ int ping_icmp(host_t *host, ping_t *ping) {
 						}
 					}
 				}else{
-					SPINE_LOG_DEBUG(("Host[%i] DEBUG: Exceeded Host Timeout, Retrying", host->id));
+					if (is_debug_device(host->id)) {
+						SPINE_LOG(("Device[%i] DEBUG: Exceeded Device Timeout, Retrying", host->id));
+					}else{
+						SPINE_LOG_DEBUG(("Device[%i] DEBUG: Exceeded Device Timeout, Retrying", host->id));
+					}
 				}
 
 				total_time = 0;
@@ -524,7 +552,11 @@ int ping_udp(host_t *host, ping_t *ping) {
 	fd_set socket_fds;
 	char   *new_hostname;
 
-	SPINE_LOG_DEBUG(("Host[%i] DEBUG: Entering UDP Ping", host->id));
+	if (is_debug_device(host->id)) {
+		SPINE_LOG(("Device[%i] DEBUG: Entering UDP Ping", host->id));
+	}else{
+		SPINE_LOG_DEBUG(("Device[%i] DEBUG: Entering UDP Ping", host->id));
+	}
 
 	/* set total time */
 	total_time = 0;
@@ -535,6 +567,15 @@ int ping_udp(host_t *host, ping_t *ping) {
 	/* convert the host timeout to a double precision number in seconds */
 	host_timeout = host->ping_timeout;
 
+	/* establish timeout value */
+	if (host_timeout >= 1000) {
+		timeout.tv_sec  = rint(floor(host_timeout / 1000));
+		timeout.tv_usec = (timeout.tv_sec * 1000000) - (host_timeout * 1000);
+	}else{
+		timeout.tv_sec  = 0;
+		timeout.tv_usec = (host_timeout * 1000);
+	}
+
 	/* initilize the socket */
 	udp_socket = socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP);
 
@@ -608,8 +649,12 @@ int ping_udp(host_t *host, ping_t *ping) {
 						return_code = read(udp_socket, socket_reply, BUFSIZE);
 
 						if ((return_code == -1) && ((errno == ECONNRESET) || (errno == ECONNREFUSED))) {
-							SPINE_LOG_DEBUG(("Host[%i] DEBUG: UDP Host Alive, Try Count:%i, Time:%.4f ms", host->id, retry_count+1, (total_time)));
-							snprintf(ping->ping_response, SMALL_BUFSIZE, "UDP: Host is Alive");
+							if (is_debug_device(host->id)) {
+								SPINE_LOG(("Device[%i] DEBUG: UDP Device Alive, Try Count:%i, Time:%.4f ms", host->id, retry_count+1, (total_time)));
+							}else{
+								SPINE_LOG_DEBUG(("Device[%i] DEBUG: UDP Device Alive, Try Count:%i, Time:%.4f ms", host->id, retry_count+1, (total_time)));
+							}
+							snprintf(ping->ping_response, SMALL_BUFSIZE, "UDP: Device is Alive");
 							snprintf(ping->ping_status, 50, "%.5f", total_time);
 							free(new_hostname);
 							close(udp_socket);
@@ -619,9 +664,10 @@ int ping_udp(host_t *host, ping_t *ping) {
 				}else if (return_code == -1) {
 					if (errno == EINTR) {
 						/* interrupted, try again */
+						usleep(10000);
 						goto wait_more;
 					}else{
-						snprintf(ping->ping_response, SMALL_BUFSIZE, "UDP: Host is Down");
+						snprintf(ping->ping_response, SMALL_BUFSIZE, "UDP: Device is Down");
 						snprintf(ping->ping_status, 50, "%.5f", total_time);
 						free(new_hostname);
 						close(udp_socket);
@@ -631,7 +677,11 @@ int ping_udp(host_t *host, ping_t *ping) {
 					/* timeout */
 				}
 
-				SPINE_LOG_DEBUG(("Host[%i] DEBUG: UDP Timeout, Try Count:%i, Time:%.4f ms", host->id, retry_count+1, (total_time)));
+				if (is_debug_device(host->id)) {
+					SPINE_LOG(("Device[%i] DEBUG: UDP Timeout, Try Count:%i, Time:%.4f ms", host->id, retry_count+1, (total_time)));
+				}else{
+					SPINE_LOG_DEBUG(("Device[%i] DEBUG: UDP Timeout, Try Count:%i, Time:%.4f ms", host->id, retry_count+1, (total_time)));
+				}
 
 				retry_count++;
 				#ifndef SOLAR_THREAD
@@ -678,7 +728,11 @@ int ping_tcp(host_t *host, ping_t *ping) {
 	int    return_code;
 	char   *new_hostname;
 
-	SPINE_LOG_DEBUG(("Host[%i] DEBUG: Entering TCP Ping", host->id));
+	if (is_debug_device(host->id)) {
+		SPINE_LOG(("Device[%i] DEBUG: Entering TCP Ping", host->id));
+	}else{
+		SPINE_LOG_DEBUG(("Device[%i] DEBUG: Entering TCP Ping", host->id));
+	}
 
 	/* remove "tcp:" from hostname */
 	new_hostname = remove_tcp_udp_from_hostname(host->hostname);
@@ -728,8 +782,12 @@ int ping_tcp(host_t *host, ping_t *ping) {
 
 				if (((return_code == -1) && (errno == ECONNREFUSED)) ||
 					(return_code == 0)) {
-					SPINE_LOG_DEBUG(("Host[%i] DEBUG: TCP Host Alive, Try Count:%i, Time:%.4f ms", host->id, retry_count+1, (total_time)));
-					snprintf(ping->ping_response, SMALL_BUFSIZE, "TCP: Host is Alive");
+					if (is_debug_device(host->id)) {
+						SPINE_LOG(("Device[%i] DEBUG: TCP Device Alive, Try Count:%i, Time:%.4f ms", host->id, retry_count+1, (total_time)));
+					}else{
+						SPINE_LOG_DEBUG(("Device[%i] DEBUG: TCP Device Alive, Try Count:%i, Time:%.4f ms", host->id, retry_count+1, (total_time)));
+					}
+					snprintf(ping->ping_response, SMALL_BUFSIZE, "TCP: Device is Alive");
 					snprintf(ping->ping_status, 50, "%.5f", total_time);
 					free(new_hostname);
 					close(tcp_socket);
@@ -1149,32 +1207,75 @@ void update_host_status(int status, host_t *host, ping_t *ping, int availability
 		if ((host->status == HOST_UP) || (host->status == HOST_RECOVERING)) {
 			/* log ping result if we are to use a ping for reachability testing */
 			if (availability_method == AVAIL_SNMP_AND_PING) {
-				SPINE_LOG_HIGH(("Host[%i] PING Result: %s", host->id, ping->ping_response));
-				SPINE_LOG_HIGH(("Host[%i] SNMP Result: %s", host->id, ping->snmp_response));
+				if (is_debug_device(host->id)) {
+					SPINE_LOG(("Device[%i] PING Result: %s", host->id, ping->ping_response));
+					SPINE_LOG(("Device[%i] SNMP Result: %s", host->id, ping->snmp_response));
+				}else{
+					SPINE_LOG_HIGH(("Device[%i] PING Result: %s", host->id, ping->ping_response));
+					SPINE_LOG_HIGH(("Device[%i] SNMP Result: %s", host->id, ping->snmp_response));
+				}
 			}else if (availability_method == AVAIL_SNMP_OR_PING) {
-				SPINE_LOG_HIGH(("Host[%i] PING Result: %s", host->id, ping->ping_response));
-				SPINE_LOG_HIGH(("Host[%i] SNMP Result: %s", host->id, ping->snmp_response));
+				if (is_debug_device(host->id)) {
+					SPINE_LOG(("Device[%i] PING Result: %s", host->id, ping->ping_response));
+					SPINE_LOG(("Device[%i] SNMP Result: %s", host->id, ping->snmp_response));
+				}else{
+					SPINE_LOG_HIGH(("Device[%i] PING Result: %s", host->id, ping->ping_response));
+					SPINE_LOG_HIGH(("Device[%i] SNMP Result: %s", host->id, ping->snmp_response));
+				}
 			}else if (availability_method == AVAIL_SNMP) {
 				if ((strlen(host->snmp_community) == 0) && (host->snmp_version < 3)) {
-					SPINE_LOG_HIGH(("Host[%i] SNMP Result: Device does not require SNMP", host->id));
+					if (is_debug_device(host->id)) {
+						SPINE_LOG(("Device[%i] SNMP Result: Device does not require SNMP", host->id));
+					}else{
+						SPINE_LOG_HIGH(("Device[%i] SNMP Result: Device does not require SNMP", host->id));
+					}
 				}else{
-					SPINE_LOG_HIGH(("Host[%i] SNMP Result: %s", host->id, ping->snmp_response));
+					if (is_debug_device(host->id)) {
+						SPINE_LOG(("Device[%i] SNMP Result: %s", host->id, ping->snmp_response));
+					}else{
+						SPINE_LOG_HIGH(("Device[%i] SNMP Result: %s", host->id, ping->snmp_response));
+					}
 				}
 			}else if (availability_method == AVAIL_NONE) {
-				SPINE_LOG_HIGH(("Host[%i] No Host Availability Method Selected", host->id));
+				if (is_debug_device(host->id)) {
+					SPINE_LOG(("Device[%i] No Device Availability Method Selected", host->id));
+				}else{
+					SPINE_LOG_HIGH(("Device[%i] No Device Availability Method Selected", host->id));
+				}
 			}else{
-				SPINE_LOG_HIGH(("Host[%i] PING: Result %s", host->id, ping->ping_response));
+				if (is_debug_device(host->id)) {
+					SPINE_LOG(("Device[%i] PING: Result %s", host->id, ping->ping_response));
+				}else{
+					SPINE_LOG_HIGH(("Device[%i] PING: Result %s", host->id, ping->ping_response));
+				}
 			}
 		}else{
 			if (availability_method == AVAIL_SNMP_AND_PING) {
-				SPINE_LOG_HIGH(("Host[%i] PING Result: %s", host->id, ping->ping_response));
-				SPINE_LOG_HIGH(("Host[%i] SNMP Result: %s", host->id, ping->snmp_response));
+				if (is_debug_device(host->id)) {
+					SPINE_LOG(("Device[%i] PING Result: %s", host->id, ping->ping_response));
+					SPINE_LOG(("Device[%i] SNMP Result: %s", host->id, ping->snmp_response));
+				}else{
+					SPINE_LOG_HIGH(("Device[%i] PING Result: %s", host->id, ping->ping_response));
+					SPINE_LOG_HIGH(("Device[%i] SNMP Result: %s", host->id, ping->snmp_response));
+				}
 			}else if (availability_method == AVAIL_SNMP) {
-				SPINE_LOG_HIGH(("Host[%i] SNMP Result: %s", host->id, ping->snmp_response));
+				if (is_debug_device(host->id)) {
+					SPINE_LOG(("Device[%i] SNMP Result: %s", host->id, ping->snmp_response));
+				}else{
+					SPINE_LOG_HIGH(("Device[%i] SNMP Result: %s", host->id, ping->snmp_response));
+				}
 			}else if (availability_method == AVAIL_NONE) {
-				SPINE_LOG_HIGH(("Host[%i] No Host Availability Method Selected", host->id));
+				if (is_debug_device(host->id)) {
+					SPINE_LOG(("Device[%i] No Device Availability Method Selected", host->id));
+				}else{
+					SPINE_LOG_HIGH(("Device[%i] No Device Availability Method Selected", host->id));
+				}
 			}else{
-				SPINE_LOG_HIGH(("Host[%i] PING Result: %s", host->id, ping->ping_response));
+				if (is_debug_device(host->id)) {
+					SPINE_LOG(("Device[%i] PING Result: %s", host->id, ping->ping_response));
+				}else{
+					SPINE_LOG_HIGH(("Device[%i] PING Result: %s", host->id, ping->ping_response));
+				}
 			}
 		}
 	}
@@ -1182,9 +1283,9 @@ void update_host_status(int status, host_t *host, ping_t *ping, int availability
 	/* if there is supposed to be an event generated, do it */
 	if (issue_log_message) {
 		if (host->status == HOST_DOWN) {
-			SPINE_LOG(("Host[%i] Hostname[%s] ERROR: HOST EVENT: Host is DOWN Message: %s", host->id, host->hostname, host->status_last_error));
+			SPINE_LOG(("Device[%i] Hostname[%s] ERROR: HOST EVENT: Device is DOWN Message: %s", host->id, host->hostname, host->status_last_error));
 		}else{
-			SPINE_LOG(("Host[%i] Hostname[%s] NOTICE: HOST EVENT: Host Returned from DOWN State", host->id, host->hostname));
+			SPINE_LOG(("Device[%i] Hostname[%s] NOTICE: HOST EVENT: Device Returned from DOWN State", host->id, host->hostname));
 		}
 	}
 }
