@@ -1621,7 +1621,7 @@ void poll_host(int host_id, int host_thread, int last_host_thread, int host_data
 	}
 
 	if (error_len > 0) {
-		SPINE_LOG(("WARNING: Invalid Response(s), Errors[%i] Device[%i] Thread[%i] DataSources[%s]", errors, host_id, host_thread, error_string));
+		SPINE_LOG(("WARNING: Invalid Response(s), Errors[%i] Device[%i] Thread[%i] DS[%s]", errors, host_id, host_thread, error_string));
 	}
 
 	free(error_string);
@@ -1877,11 +1877,11 @@ char *exec_poll(host_t *current_host, char *command) {
 			}
 		case 0:
 			#ifdef USING_TPOPEN
-			SPINE_LOG(("Device[%i] ERROR: The POPEN timed out", current_host->id));
+			SPINE_LOG_MEDIUM(("Device[%i] ERROR: The POPEN timed out", current_host->id));
 
 			close_fd = FALSE;
 			#else
-			SPINE_LOG(("Device[%i] ERROR: The NIFTY POPEN timed out", current_host->id));
+			SPINE_LOG_MEDIUM(("Device[%i] ERROR: The NIFTY POPEN timed out", current_host->id));
 
 			pid = nft_pchild(cmd_fd);
 			kill(pid, SIGKILL);
