@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:
  +-------------------------------------------------------------------------+
- | Copyright (C) 2002-2012 The Cacti Group                                 |
+ | Copyright (C) 2004-2017 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -48,11 +48,86 @@
  *
  */
 void snmp_spine_init(void) {
-#ifdef USE_NET_SNMP
-	/* Only do numeric output */
-	#ifdef NETSNMP_DS_LIB_PRINT_NUMERIC_ENUM
-		netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_PRINT_NUMERIC_ENUM, 1);
-	#endif
+
+/* Only do numeric output */
+#ifdef NETSNMP_DS_LIB_PRINT_NUMERIC_ENUM
+	netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_PRINT_NUMERIC_ENUM, 1);
+#endif
+
+/* Prevent update of the snmpapp.conf file */
+#ifdef NETSNMP_DS_LIB_DONT_PERSIST_STATE
+	netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_DONT_PERSIST_STATE, 1);
+#endif
+
+/* Prevent update of the snmpapp.conf file */
+#ifdef NETSNMP_DS_LIB_DISABLE_PERSISTENT_LOAD
+	netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_DISABLE_PERSISTENT_LOAD, 1);
+#endif
+
+#ifdef NETSNMP_DS_LIB_DONT_PRINT_UNITS
+	netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_DONT_PRINT_UNITS, 1);
+#endif
+
+netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_QUICK_PRINT, 1);
+netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_QUICKE_PRINT, 1);
+netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_PRINT_BARE_VALUE, 1);
+netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_NUMERIC_TIMETICKS, 1);
+
+#if defined(VERIFY_PACKAGE_VERSION) && defined(PACKAGE_VERSION)
+	/* check that the headers we compiled with match the library we linked with */
+	SPINE_LOG_DEBUG(("DEBUG: SNMP Header Version is %s", PACKAGE_VERSION));
+	SPINE_LOG_DEBUG(("DEBUG: SNMP Library Version is %s", netsnmp_get_version()));
+
+	if(STRMATCH(PACKAGE_VERSION,netsnmp_get_version())) {
+		init_snmp("spine");
+	}else{
+		/* report the error and quit spine */
+		die("ERROR: SNMP Library Version Mismatch (%s vs %s)",PACKAGE_VERSION,netsnmp_get_version());
+	}
+#else
+	SPINE_LOG_DEBUG(("DEBUG: Issues with SNMP Header Version information, assuming old version of Net-SNMP."));
+	init_snmp("spine");
+#endif
+}
+
+/*! \fn void snmp_spine_close()
+ *  \brief wrapper function for the snmp_shutdown function
+ *
+ *	Closes the snmp api for the given application ID
+ *
+ */
+void snmp_spine_close(void) {
+	snmp_shutdown("spine");
+}
+
+/*! \fn void *snmp_host_init(int host_id, char *hostname, int snmp_version,
+ * char *snmp_community, char *snmp_username, char *snmp_password,
+ * char *snmp_auth_protocol, char *snmp_priv_passphrase, char *snmp_priv_protocol,
+ * char *snmp_context, char *snmp_engine_id, int snmp_port, int snmp_timeout)
+ *  \brief initializes an snmp_session object for a Spine host
+ *
+ *	This function will initialize NET-SNMP for the Spine host
+ *  in question.
+ *
+ */
+void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_community,
+					char *snmp_username, char *snmp_password, char *snmp_auth_protocol,
+					char *snmp_priv_passphrase, char *snmp_priv_protocol,
+					char *snmp_context, char *snmp_engine_id, int snmp_port, int snmp_timeout) {
+
+	void   *sessp = NULL;
+	struct snmp_session session;
+	char   hostnameport[BUFSIZE];
+
+	/* initialize SNMP */
+	snmp_sess_init(&session);
+
+	/* Bind to snmp_clientaddr if specified */
+	if (NULL != set.snmp_clientaddr  && strlen(set.snmp_clientaddr) > 0) {
+		#if SNMP_LOCALNAME == 1
+		session.localname = strdup(set.snmp_clientaddr);
+		#endif
+	}
 
 	/* Prevent update of the snmpapp.conf file */
 	#ifdef NETSNMP_DS_LIB_DONT_PERSIST_STATE
@@ -73,96 +148,6 @@ void snmp_spine_init(void) {
 	netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_PRINT_BARE_VALUE, 1);
 	netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_NUMERIC_TIMETICKS, 1);
 
-	#if defined(VERIFY_PACKAGE_VERSION) && defined(PACKAGE_VERSION)
-		/* check that the headers we compiled with match the library we linked with -
-		   apparently not defined in UCD-SNMP...
-		*/
-		SPINE_LOG_DEBUG(("DEBUG: SNMP Header Version is %s", PACKAGE_VERSION));
-		SPINE_LOG_DEBUG(("DEBUG: SNMP Library Version is %s", netsnmp_get_version()));
-
-		if(STRMATCH(PACKAGE_VERSION,netsnmp_get_version())) {
-			init_snmp("spine");
-		}else{
-			/* report the error and quit spine */
-			die("ERROR: SNMP Library Version Mismatch (%s vs %s)",PACKAGE_VERSION,netsnmp_get_version());
-		}
-	#else
-		SPINE_LOG_DEBUG(("DEBUG: Issues with SNMP Header Version information, assuming old version of Net-SNMP."));
-		init_snmp("spine");
-	#endif
-#else
-	ds_set_boolean(DS_LIBRARY_ID, DS_LIB_QUICK_PRINT, 1);
-	ds_set_boolean(DS_LIBRARY_ID, DS_LIB_PRINT_BARE_VALUE, 1);
-	ds_set_boolean(DS_LIBRARY_ID, DS_LIB_NUMERIC_TIMETICKS, 1);
-
-	init_snmp("spine");
-#endif
-}
-
-/*! \fn void snmp_spine_close()
- *  \brief wrapper function for the snmp_shutdown function
- *
- *	Closes the snmp api for the given application ID
- *
- */
-void snmp_spine_close(void) {
-	snmp_shutdown("spine");
-}
-
-/*! \fn void *snmp_host_init(int host_id, char *hostname, int snmp_version,
- * char *snmp_community, char *snmp_username, char *snmp_password,
- * char *snmp_auth_protocol, char *snmp_priv_passphrase, char *snmp_priv_protocol,
- * char *snmp_context, int snmp_port, int snmp_timeout)
- *  \brief initializes an snmp_session object for a Spine host
- *
- *	This function will initialize NET-SNMP or UCD-SNMP for the Spine host
- *  in question.
- *
- */
-void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_community,
-					char *snmp_username, char *snmp_password, char *snmp_auth_protocol,
-					char *snmp_priv_passphrase, char *snmp_priv_protocol,
-					char *snmp_context, int snmp_port, int snmp_timeout) {
-
-	void   *sessp = NULL;
-	struct snmp_session session;
-	char   hostnameport[BUFSIZE];
-
-	/* initialize SNMP */
-	snmp_sess_init(&session);
-
-	#ifdef USE_NET_SNMP
-		/* Bind to snmp_clientaddr if specified */
-		if (NULL != set.snmp_clientaddr  && strlen(set.snmp_clientaddr) > 0) {
-			#if SNMP_LOCALNAME == 1
-			session.localname = strdup(set.snmp_clientaddr);
-			#endif
-		}
-
-		/* Prevent update of the snmpapp.conf file */
-		#ifdef NETSNMP_DS_LIB_DONT_PERSIST_STATE
-			netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_DONT_PERSIST_STATE, 1);
-		#endif
-
-		/* Prevent update of the snmpapp.conf file */
-		#ifdef NETSNMP_DS_LIB_DISABLE_PERSISTENT_LOAD
-			netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_DISABLE_PERSISTENT_LOAD, 1);
-		#endif
-
-		#ifdef NETSNMP_DS_LIB_DONT_PRINT_UNITS
-			netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_DONT_PRINT_UNITS, 1);
-		#endif
-
-		netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_QUICK_PRINT, 1);
-		netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_QUICKE_PRINT, 1);
-		netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_PRINT_BARE_VALUE, 1);
-		netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_NUMERIC_TIMETICKS, 1);
-	#else
-		ds_set_boolean(DS_LIBRARY_ID, DS_LIB_QUICK_PRINT, 1);
-		ds_set_boolean(DS_LIBRARY_ID, DS_LIB_PRINT_BARE_VALUE, 1);
-		ds_set_boolean(DS_LIBRARY_ID, DS_LIB_NUMERIC_TIMETICKS, 1);
-	#endif
-
 	session.securityEngineID = 0;
 	session.securityEngineIDLen = 0;
 
@@ -175,6 +160,9 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 	session.contextName = 0;
 	session.contextNameLen = 0;
 
+	session.contextEngineID = 0;
+	session.contextEngineIDLen = 0;
+
 	/* verify snmp version is accurate */
 	if (snmp_version == 2) {
 		session.version       = SNMP_VERSION_2c;
@@ -186,13 +174,13 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 		session.version       = SNMP_VERSION_3;
 		session.securityModel = USM_SEC_MODEL_NUMBER;
 	}else {
-		SPINE_LOG(("Host[%i] ERROR: SNMP Version Error for Host '%s'", host_id, hostname));
+		SPINE_LOG(("Device[%i] ERROR: SNMP Version Error for Device '%s'", host_id, hostname));
 		return 0;
 	}
 
 	snprintf(hostnameport, BUFSIZE, "%s:%i", hostname, snmp_port);
 	session.peername    = hostnameport;
-	session.retries     = 3;
+	session.retries     = set.snmp_retries;
 	session.remote_port = snmp_port;
 	session.timeout     = (snmp_timeout * 1000); /* net-snmp likes microseconds */
 
@@ -209,6 +197,11 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 			session.contextNameLen       = strlen(session.contextName);
 		}
 
+		if (snmp_engine_id && strlen(snmp_engine_id)) {
+			session.contextEngineID      = snmp_engine_id;
+			session.contextEngineIDLen   = strlen(session.contextEngineID);
+		}
+
 		session.securityAuthKeyLen   = USM_AUTH_KU_LEN;
 
 		/* set the authentication protocol */
@@ -281,7 +274,11 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 	thread_mutex_unlock(LOCK_SNMP);
 
 	if (!sessp) {
-		SPINE_LOG_MEDIUM(("ERROR: Problem initializing SNMP session '%s'", hostname));
+		if (is_debug_device(host_id)) {
+			SPINE_LOG(("ERROR: Problem initializing SNMP session '%s'", hostname));
+		}else{
+			SPINE_LOG_MEDIUM(("ERROR: Problem initializing SNMP session '%s'", hostname));
+		}
 	}
 
 	return sessp;
@@ -332,7 +329,7 @@ char *snmp_get(host_t *current_host, char *snmp_oid) {
 		pdu       = snmp_pdu_create(SNMP_MSG_GET);
 
 		if (!snmp_parse_oid(snmp_oid, anOID, &anOID_len)) {
-			SPINE_LOG(("Host[%i] ERROR: SNMP Get Problems parsing SNMP OID %s", current_host->id, snmp_oid));
+			SPINE_LOG(("Device[%i] ERROR: SNMP Get Problems parsing SNMP OID %s", current_host->id, snmp_oid));
 			SET_UNDEFINED(result_string);
 			return result_string;
 		}else{
@@ -356,11 +353,7 @@ char *snmp_get(host_t *current_host, char *snmp_oid) {
 				if (response->errstat == SNMP_ERR_NOERROR) {
 					vars = response->variables;
 
-					#ifdef USE_NET_SNMP
 					snmp_snprint_value(temp_result, RESULTS_BUFFER, vars->name, vars->name_length, vars);
-					#else
-					sprint_value(temp_result, anOID, anOID_len, vars);
-					#endif
 
 					snprintf(result_string, RESULTS_BUFFER, "%s", trim(temp_result));
 				}
@@ -416,7 +409,7 @@ char *snmp_getnext(host_t *current_host, char *snmp_oid) {
 		pdu       = snmp_pdu_create(SNMP_MSG_GETNEXT);
 
 		if (!snmp_parse_oid(snmp_oid, anOID, &anOID_len)) {
-			SPINE_LOG(("Host[%i] ERROR: SNMP Getnext Problems parsing SNMP OID %s", current_host->id, snmp_oid));
+			SPINE_LOG(("Device[%i] ERROR: SNMP Getnext Problems parsing SNMP OID %s", current_host->id, snmp_oid));
 			SET_UNDEFINED(result_string);
 			return result_string;
 		}else{
@@ -441,13 +434,9 @@ char *snmp_getnext(host_t *current_host, char *snmp_oid) {
 					vars = response->variables;
 
 					if (vars != NULL) {
-						#ifdef USE_NET_SNMP
 						snmp_snprint_value(temp_result, RESULTS_BUFFER, vars->name, vars->name_length, vars);
-						#else
-						sprint_value(temp_result, anOID, anOID_len, vars);
-						#endif
 
-						snprintf(result_string, RESULTS_BUFFER, "%s", trim(temp_result));
+						snprintf(result_string, RESULTS_BUFFER, "%s", trim(strip_alpha(temp_result)));
 					}else{
 						SET_UNDEFINED(result_string);
 						status = STAT_ERROR;
@@ -494,17 +483,20 @@ int snmp_count(host_t *current_host, char *snmp_oid) {
 	int    ok = 1;
 	int    error_occurred = 0;
 	int    count = 0;
-	char   temp_result[RESULTS_BUFFER];
 
 	status = STAT_DESCRIP_ERROR;
 
-	SPINE_LOG_DEBUG(("NOTE: walk starts at OID %s", snmp_oid));
+	if (is_debug_device(current_host->id)) {
+		SPINE_LOG(("NOTE: walk starts at OID %s", snmp_oid));
+	}else{
+		SPINE_LOG_DEBUG(("NOTE: walk starts at OID %s", snmp_oid));
+	}
 
 	if (current_host->snmp_session != NULL) {
 		rootlen = MAX_OID_LEN;
 		/* parse input parm to an array for use with snmp functions */
 		if (!snmp_parse_oid(snmp_oid, root, &rootlen)) {
-			SPINE_LOG(("Host[%i] ERROR: SNMP Count Problems parsing SNMP OID %s", current_host->id, snmp_oid));
+			SPINE_LOG(("Device[%i] ERROR: SNMP Count Problems parsing SNMP OID %s", current_host->id, snmp_oid));
 			return count;
 		}
 		memmove(anOID, root, rootlen * sizeof(oid));
@@ -595,7 +587,7 @@ void snmp_snprint_value(char *obuf, size_t buf_len, const oid *objid, size_t obj
 
 	if (buf_len > 0) {
 		if ((buf = (u_char *) calloc(buf_len, 1)) != 0) {
-			sprint_realloc_by_type(&buf, &buf_len, &out_len, 1, variable, NULL, NULL, NULL);
+			sprint_realloc_by_type(&buf, &buf_len, &out_len, 0, variable, NULL, NULL, NULL);
 			snprintf(obuf, buf_len, "%s", buf);
 		}else{
 			SET_UNDEFINED(obuf);
@@ -637,7 +629,7 @@ void snmp_get_multi(host_t *current_host, snmp_oids_t *snmp_oids, int num_oids)
 		namep->name_len = MAX_OID_LEN;
 
 		if (!snmp_parse_oid(snmp_oids[i].oid, namep->name, &namep->name_len)) {
-			SPINE_LOG(("Host[%i] ERROR: Problems parsing Multi SNMP OID! (oid: %s), Set MAX_OIDS to 1 for this host to isolate bad OID", current_host->id, snmp_oids[i].oid));
+			SPINE_LOG(("Device[%i] ERROR: Problems parsing Multi SNMP OID! (oid: %s), Set MAX_OIDS to 1 for this host to isolate bad OID", current_host->id, snmp_oids[i].oid));
 
 			/* Mark this OID as "bad" */
 			SET_UNDEFINED(snmp_oids[i].result);
@@ -666,15 +658,11 @@ void snmp_get_multi(host_t *current_host, snmp_oids_t *snmp_oids, int num_oids)
 			if (response->errstat == SNMP_ERR_NOERROR) {
 				vars = response->variables;
 
-				for(i = 0; i < num_oids && vars; i++) {
+				for (i = 0; i < num_oids && vars; i++) {
 					if (!IS_UNDEFINED(snmp_oids[i].result)) {
-						#ifdef USE_NET_SNMP
 						snmp_snprint_value(temp_result, RESULTS_BUFFER, vars->name, vars->name_length, vars);
-						#else
-						sprint_value(temp_result, vars->name, vars->name_length, vars);
-						#endif
 
-						snprintf(snmp_oids[i].result, RESULTS_BUFFER, "%s", trim(temp_result));
+						snprintf(snmp_oids[i].result, RESULTS_BUFFER, "%s", trim(strip_alpha(temp_result)));
 						
 						vars = vars->next_variable;
 					}
@@ -715,14 +703,12 @@ void snmp_get_multi(host_t *current_host, snmp_oids_t *snmp_oids, int num_oids)
 						/* all OID's errored out so exit cleanly */
 						status = STAT_SUCCESS;
 					}
-				}else{
-					status = STAT_DESCRIP_ERROR;
 				}
 			}
 		}
 	}
 
-	if (status != STAT_SUCCESS) {
+	if (status == STAT_TIMEOUT) {
 		current_host->ignore_host = 1;
 		for (i = 0; i < num_oids; i++) {
 			SET_UNDEFINED(snmp_oids[i].result);
@@ -732,4 +718,6 @@ void snmp_get_multi(host_t *current_host, snmp_oids_t *snmp_oids, int num_oids)
 	if (response != NULL) {
 		snmp_free_pdu(response);
 	}
+
+	free(name);
 }
