@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:
  +-------------------------------------------------------------------------+
- | Copyright (C) 2002-2013 The Cacti Group                                 |
+ | Copyright (C) 2004-2017 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -155,10 +155,8 @@
 
 /* threads constants */
 #define LOCK_SNMP 0
-#define LOCK_THREAD 1
 #define LOCK_SETEUID 2
 #define LOCK_GHBN 3
-#define LOCK_PIPE 4
 #define LOCK_SYSLOG 5
 #define LOCK_PHP 6
 #define LOCK_PHP_PROC_0 7
@@ -171,12 +169,11 @@
 #define LOCK_PHP_PROC_7 14
 #define LOCK_PHP_PROC_8 15
 #define LOCK_PHP_PROC_9 16
+#define LOCK_PEND 17
 
 #define LOCK_SNMP_O 0
-#define LOCK_THREAD_O 1
 #define LOCK_SETEUID_O 2
 #define LOCK_GHBN_O 3
-#define LOCK_PIPE_O 4
 #define LOCK_SYSLOG_O 5
 #define LOCK_PHP_O 6
 #define LOCK_PHP_PROC_0_O 7
@@ -189,6 +186,7 @@
 #define LOCK_PHP_PROC_7_O 14
 #define LOCK_PHP_PROC_8_O 15
 #define LOCK_PHP_PROC_9_O 16
+#define LOCK_PEND_O 17
 
 /* poller actions */
 #define POLLER_ACTION_SNMP 0
@@ -263,6 +261,11 @@
 #define SNMP_3 3
 #define SNMP_NONE 4
 
+/* Constants for remote polling */
+#define REMOTE_ONLINE 0
+#define REMOTE_OFFLINE 1
+#define REMOTE_RECOVERY 2
+
 /* These are used to perform string matches, returning TRUE/VALUE values.
  * For strcmp() this is not really that useful, but the case-insensitive
  * one has slight portability issues. Better to abstract them here.
@@ -317,7 +320,6 @@ typedef struct config_struct {
 	char   dbuser[SMALL_BUFSIZE];
 	char   dbpass[SMALL_BUFSIZE];
 	unsigned int dbport;
-	unsigned int pre087g;
 	int    dbversion;
 	/* path information */
 	char   path_logfile[SMALL_BUFSIZE];
@@ -329,6 +331,8 @@ typedef struct config_struct {
 	int    log_perror;
 	int    log_pwarn;
 	int    log_pstats;
+	char   selective_device_debug[SMALL_BUFSIZE];
+	int    spine_log_level;
 	/* ping settings */
 	int    icmp_avail;
 	int    availability_method;
@@ -341,6 +345,7 @@ typedef struct config_struct {
 	int    snmp_max_get_size;
 	int    snmp_retries;
 	char   snmp_clientaddr[SMALL_BUFSIZE];
+	int    mibs;
 	/* PHP Script Server Options */
 	int    php_required;
 	int    php_initialized;
@@ -348,6 +353,15 @@ typedef struct config_struct {
 	int    php_current_server;
 	/* Exit code if we need it */
 	int    exit_code;
+	/* Remote polling mode */
+	int    mode;
+	/* remote database connection information */
+	char   rdbhost[SMALL_BUFSIZE];
+	char   rdbdb[SMALL_BUFSIZE];
+	char   rdbuser[SMALL_BUFSIZE];
+	char   rdbpass[SMALL_BUFSIZE];
+	unsigned int rdbport;
+	int    rdbversion;
 } config_t;
 
 /*! Target Structure
@@ -371,6 +385,7 @@ typedef struct target_struct {
 	char   snmp_priv_passphrase[200];
 	char   snmp_priv_protocol[7];
 	char   snmp_context[65];
+	char   snmp_engine_id[30];
 	int    snmp_port;
 	int    snmp_timeout;
 	int    availability_method;
@@ -408,6 +423,8 @@ typedef struct poller_thread {
 	int last_host_thread;
 	int host_data_ids;
 	char *host_time;
+	double host_time_double;
+	sem_t *thread_init_sem;
 } poller_thread_t;
 
 /*! PHP Script Server Structure
@@ -440,9 +457,16 @@ typedef struct host_struct {
 	char   snmp_priv_passphrase[200];
 	char   snmp_priv_protocol[7];
 	char   snmp_context[65];
+	char   snmp_engine_id[30];
 	int    snmp_port;
 	int    snmp_timeout;
 	int    snmp_retries;
+	char   snmp_sysDescr[300];
+	char   snmp_sysObjectID[64];
+	u_int  snmp_sysUpTimeInstance;
+	char   snmp_sysContact[300];
+	char   snmp_sysName[300];
+	char   snmp_sysLocation[300];
 	int    max_oids;
 	int    availability_method;
 	int    ping_method;
@@ -509,7 +533,6 @@ extern config_t set;
 extern php_t  *php_processes;
 extern char   start_datetime[20];
 extern char   config_paths[CONFIG_PATHS][BUFSIZE];
-extern int    active_threads;
-extern int    thread_ready;
+extern sem_t  active_threads;
 
 #endif /* not _SPINE_H_ */
