@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:
  +-------------------------------------------------------------------------+
- | Copyright (C) 2002-2013 The Cacti Group                                 |
+ | Copyright (C) 2004-2017 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -61,6 +61,11 @@ int db_insert(MYSQL *mysql, const char *query) {
 			if (mysql_query(mysql, query)) {
 				error = mysql_errno(mysql);
 
+				if (error == 2013 && errno == EINTR) {
+					usleep(50000);
+					continue;
+				}
+
 				if ((error == 1213) || (error == 1205)) {
 					usleep(50000);
 					error_count++;
@@ -71,8 +76,7 @@ int db_insert(MYSQL *mysql, const char *query) {
 					}
 
 					continue;
-				}else if (error == 2006) {
-					SPINE_LOG(("WARNING: SQL Failed! Error:'%i', Message:'%s', Attempting to Reconnect", error, mysql_error(mysql)));
+				}else if (error == 2006 && errno == EINTR) {
 					db_disconnect(mysql);
 					usleep(50000);
 					db_connect(set.dbdb, mysql);
@@ -80,7 +84,7 @@ int db_insert(MYSQL *mysql, const char *query) {
 
 					if (error_count > 30) {
 						die("FATAL: Too many Reconnect Attempts!\n");
-                                        }
+					}
 
 					continue;
 				}else{
@@ -124,6 +128,11 @@ MYSQL_RES *db_query(MYSQL *mysql, const char *query) {
 		if (mysql_query(mysql, query)) {
 			error = mysql_errno(mysql);
 
+			if (error == 2013 && errno == EINTR) {
+				usleep(50000);
+				continue;
+			}
+
 			if ((error == 1213) || (error == 1205)) {
 				#ifndef SOLAR_THREAD
 				usleep(50000);
@@ -135,8 +144,7 @@ MYSQL_RES *db_query(MYSQL *mysql, const char *query) {
 				}
 
 				continue;
-			}else if (error == 2006) {
-				SPINE_LOG(("WARNING: SQL Failed! Error:'%i', Message:'%s', Attempting to Reconnect", error, mysql_error(mysql)));
+			}else if (error == 2006 && errno == EINTR) {
 				db_disconnect(mysql);
 				usleep(50000);
 				db_connect(set.dbdb, mysql);
@@ -177,28 +185,51 @@ void db_connect(const char *database, MYSQL *mysql) {
 	int    wtimeout;
 	int    options_error;
 	int    success;
+	int    error;
+	MYSQL  *connect_error;
 	char   *hostname;
 	char   *socket = NULL;
 	struct stat socket_stat;
 
-	if ((hostname = strdup(set.dbhost)) == NULL) {
-		die("FATAL: malloc(): strdup() failed");
-	}
-
 	/* see if the hostname variable is a file reference.  If so,
 	 * and if it is a socket file, setup mysql to use it.
 	 */
-	if (stat(hostname, &socket_stat) == 0) {
-		if (socket_stat.st_mode & S_IFSOCK) {
-			socket = strdup (set.dbhost);
-			hostname = NULL;
+	if (set.poller_id > 1) {
+		if (set.mode == REMOTE_OFFLINE || set.mode == REMOTE_RECOVERY) {
+			if ((hostname = strdup(set.dbhost)) == NULL) {
+				die("FATAL: malloc(): strdup() failed");
+			}
+
+			if (stat(hostname, &socket_stat) == 0) {
+				if (socket_stat.st_mode & S_IFSOCK) {
+					socket = strdup (set.dbhost);
+					hostname = NULL;
+				}
+			}else if ((socket = strstr(hostname,":"))) {
+				*socket++ = 0x0;
+			}
+		}else{
+			if ((hostname = strdup(set.rdbhost)) == NULL) {
+				die("FATAL: malloc(): strdup() failed");
+			}
+		}
+	}else{
+		if ((hostname = strdup(set.dbhost)) == NULL) {
+			die("FATAL: malloc(): strdup() failed");
+		}
+
+		if (stat(hostname, &socket_stat) == 0) {
+			if (socket_stat.st_mode & S_IFSOCK) {
+				socket = strdup (set.dbhost);
+				hostname = NULL;
+			}
+		}else if ((socket = strstr(hostname,":"))) {
+			*socket++ = 0x0;
 		}
-	}else if ((socket = strstr(hostname,":"))) {
-		*socket++ = 0x0;
 	}
 
 	/* initialalize variables */
-	tries   = 5;
+	tries   = 10;
 	success = FALSE;
 	timeout = 5;
 	rtimeout = 10;
@@ -232,11 +263,38 @@ void db_connect(const char *database, MYSQL *mysql) {
 	}
 	#endif
 
+	#ifdef MYSQL_OPT_RETRY_COUNT
+	options_error = mysql_options(mysql, MYSQL_OPT_RETRY_COUNT, &tries);
+	if (options_error < 0) {
+		die("FATAL: MySQL options unable to set retry count option\n");
+	}
+	#endif
+
 	while (tries > 0) {
 		tries--;
 
-		if (!mysql_real_connect(mysql, hostname, set.dbuser, set.dbpass, database, set.dbport, socket, 0)) {
-			if ((mysql_errno(mysql) != 1049) && (mysql_errno(mysql) != 2005) && (mysql_errno(mysql) != 1045)) {
+		if (set.poller_id > 1) {
+			if (set.mode == REMOTE_OFFLINE || set.mode == REMOTE_RECOVERY) {
+				connect_error = mysql_real_connect(mysql, hostname, set.dbuser, set.dbpass, database, set.dbport, socket, 0);
+			}else{
+				connect_error = mysql_real_connect(mysql, hostname, set.rdbuser, set.rdbpass, set.rdbdb, set.rdbport, socket, 0);
+			}
+		}else{
+			connect_error = mysql_real_connect(mysql, hostname, set.dbuser, set.dbpass, database, set.dbport, socket, 0);
+		}
+
+		if (!connect_error) {
+			error = mysql_errno(mysql);
+			db_disconnect(mysql);
+
+			if (error == 2013 && errno == EINTR) {
+				usleep(50000);
+				tries++;
+				success = FALSE;
+				continue;
+			}
+
+			if (error != 1049 && error != 2005 && error != 1045) {
 				printf("MYSQL: Connection Failed: Error:'%u', Message:'%s'\n", mysql_errno(mysql), mysql_error(mysql));
 
 				success = FALSE;
@@ -317,3 +375,6 @@ void db_escape(MYSQL *mysql, char *output, const char *input) {
 	mysql_real_escape_string(mysql, output, input, strlen(input));
 }
 
+void db_free_result(MYSQL_RES *result) {
+	mysql_free_result(result);
+}
