@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2002-2012 The Cacti Group                                 |
+ | Copyright (C) 2004-2017 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -48,11 +48,14 @@ extern void die(const char *format, ...)
 extern void set_option(const char *setting, const char *value);
 
 /* number validation functions */
-extern int is_numeric(const char *string);
+extern int is_numeric(char *string);
 extern int is_ipaddress(const char *string);
 extern int all_digits(const char *str);
 extern int is_hexadecimal(const char * str, const short ignore_space);
 
+/* determine if a device is a debug device */
+extern int is_debug_device(int device_id);
+
 /* string and file functions */
 extern char *add_slashes(char *string);
 extern int file_exists(const char *filename);
